# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

"""
This module contains class implementing part of X-Ray advanced metrics
related to User Agent management (enable/disable/status)
"""
import os
import datetime

ADVANCED_METRICS_FLAG_ENABLED = '/opt/alt/php-xray/php/advanced_metrics.enabled'
ADVANCED_METRICS_FLAG_DISABLED = '/opt/alt/php-xray/php/advanced_metrics.disabled'


class AdvancedMetrics:
    """Main advanced metrics local utility class"""

    def enable(self):
        self._remove_flag(ADVANCED_METRICS_FLAG_DISABLED)
        self._create_flag(ADVANCED_METRICS_FLAG_ENABLED)

    def disable(self):
        self._remove_flag(ADVANCED_METRICS_FLAG_ENABLED)
        self._create_flag(ADVANCED_METRICS_FLAG_DISABLED)

    def status(self):
        if os.path.exists(ADVANCED_METRICS_FLAG_ENABLED):
            return 'enabled'
        elif os.path.exists(ADVANCED_METRICS_FLAG_DISABLED):
            return 'disabled'
        else:
            return 'none'

    def _create_flag(self, url) -> None:
        current_time = datetime.datetime.today().strftime('%Y-%m-%d %H:%M:%S')
        with open(url, 'w') as file:
            os.chmod(url, 0o644)
            file.write(current_time)

    def _remove_flag(self, url):
        if os.path.exists(url):
            os.remove(url)
