#!/bin/bash
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

# write cron with random date and time
# xray_cron_wp_plugin also used to synchronize the Imunify360 advice
xray_cron_wp_plugin=/etc/cron.d/xray_wp_plugin_install
xray_cron_update_advices=/etc/cron.d/xray_update_advices_metadata
echo "$(( RANDOM % 60 )) $(( RANDOM % 24 )) * * * root /usr/bin/flock -n /var/run/xray_sa_plugin.cronlock /usr/sbin/cl-smart-advice wordpress-plugin-install &> /dev/null" > "${xray_cron_wp_plugin}"
echo "$(( RANDOM % 60 )) $(( RANDOM % 24 )) * * * root /usr/bin/flock -n /var/run/xray_upd_metadata.cronlock /usr/sbin/cl-smart-advice update-advices-metadata &> /dev/null" > "${xray_cron_update_advices}"

# Clear redundant files with names "%{xray_cron_wp_plugin}" and "%{xray_cron_update_advices}"
# These files were created due to issue in previous versions of the package
if [ -f "%{xray_cron_wp_plugin}" ]; then
    rm -rf "%{xray_cron_wp_plugin}"
fi
if [ -f "%{xray_cron_update_advices}" ]; then
    rm -rf "%{xray_cron_update_advices}"
fi

# Make sure Smart Advice plugin directory can be symlinked even if protection against symbolic link attacks is enabled
chown root:linksafe /opt/alt/php-xray/php/smart-advice-plugin/cl-smart-advice.php 1>/dev/null 2>/dev/null

# Finalize migration
cloudlinux-xray-migrate --continue >/dev/null 2>&1 || :

# enable user-agent if AccelerateWP allowed (icon is visible in UI)
if cloudlinux-awp-admin get-options | grep "\"show_icon\": true" &> /dev/null; then
    cloudlinux-xray-manager enable-user-agent >/dev/null 2>&1 || :
fi

# Reload and restart xray-agent and xray-user-agent services
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
/bin/systemctl restart xray-agent.service >/dev/null 2>&1 || :

# restart xray-user-agent.service only if it is running
/bin/systemctl is-active --quiet xray-user-agent.service && /bin/systemctl restart xray-user-agent.service >/dev/null 2>&1 || :

# Copy xray.so for DirectAdmin
if [ -e /usr/local/directadmin/custombuild/build ]; then
  /usr/share/alt-php-xray/da_cp_xray >/dev/null 2>&1 || :
fi
# Remove previous (huge) logs from /usr/share/alt-php-xray
if compgen -G "/usr/share/alt-php-xray/manager.log*" > /dev/null; then
  rm -f /usr/share/alt-php-xray/manager.log*
fi
if compgen -G "/usr/share/alt-php-xray/agent.log*" > /dev/null; then
  rm -f /usr/share/alt-php-xray/agent.log*
fi

# Create user UID directories like /usr/share/alt-php-xray-tasks/1000
/opt/cloudlinux/venv/bin/python3 -c "from xray.create_user_uid_dirs import create_user_uid_dirs; create_user_uid_dirs()" &>/dev/null

# install of the hooks
/usr/share/cloudlinux/xray/xray_hooks.py --install >/dev/null 2>&1
